@@ -4,8 +4,10 @@
                      'License: GPL v3. Centre for Ecology and Hydrology.')
         if (length(find.package('RBGL', quiet=TRUE)) == 0){
             packageStartupMessage('NOTE: to use "bnspatial" you need first to install "RGBL" package from Bioconductor.\n',
-                                  'To install it, run the following line: \n',
+                                  'To install on R version 3.5: \n',
                                   'install.packages("BiocManager"); BiocManager::install("RBGL", version = "3.8")  \n',
+                                  'To install on R version 3.6: \n',
+                                  'install.packages("BiocManager"); BiocManager::install("RBGL")  \n',
                                   '\nbnspatial ', as.character(utils::packageVersion("bnspatial")),
                                   msg, domain=NA, appendLF=TRUE)
         } else {
